@@ -9,13 +9,13 @@ use Class::Params qw(params);
 
 # Definition.
 my $self = {};
-my $def = {
-        'par' => ['par', undef, 'SCALAR', 1],
+my $def_hr = {
+        'par' => ['par', 'SCALAR', 1],
 };
 
 # Check.
 # output_structure, definition, array of pairs (key, value).
-params($self, $def, ['bad_par', 1]);
+params($self, $def_hr, ['bad_par', 1]);
 
 # Output:
 # Unknown parameter 'bad_par'.
\ No newline at end of file
